@@ -112,7 +112,7 @@ extern int gdbg;
 #define ASSERT_SQLITE_OK(rc, db) \
 	do { \
 		if (rc!=SQLITE_OK) { \
-			proxy_error("SQLite3 error with return corde %d. Error message: %s. Shutting down.\n", rc, db?sqlite3_errmsg(db->get_db()):"The pointer to sqlite3 database is null. Cannot get error message."); \
+			proxy_error("SQLite3 error with return code %d. Error message: %s. Shutting down.\n", rc, db?(*proxy_sqlite3_errmsg)(db->get_db()):"The pointer to sqlite3 database is null. Cannot get error message."); \
 			assert(0); \
 		} \
 	} while(0)
