@@ -47,7 +47,7 @@
 
 #define SAFE_SQLITE3_STEP(_stmt) do {\
   do {\
-    rc=sqlite3_step(_stmt);\
+    rc=(*proxy_sqlite3_step)(_stmt);\
     if (rc!=SQLITE_DONE) {\
       assert(rc==SQLITE_LOCKED);\
       usleep(100);\
@@ -57,7 +57,7 @@
 
 #define SAFE_SQLITE3_STEP2(_stmt) do {\
 	do {\
-	rc=sqlite3_step(_stmt);\
+	rc=(*proxy_sqlite3_step)(_stmt);\
 		if (rc==SQLITE_LOCKED || rc==SQLITE_BUSY) {\
 			usleep(100);\
 		}\
@@ -340,6 +340,7 @@ extern ClickHouse_Server *GloClickHouseServer;
 
 static pthread_mutex_t sock_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+
 static char * ClickHouse_Server_variables_names[] = {
 	(char *)"hostname",
 	(char *)"mysql_ifaces",
@@ -1273,7 +1274,7 @@ static void *child_mysql(void *arg) {
 	fds[0].revents=0;
 	fds[0].events=POLLIN|POLLOUT;
 	free(arg);
-	sess->client_myds->myprot.generate_pkt_initial_handshake(true,NULL,NULL, &sess->thread_session_id);
+	sess->client_myds->myprot.generate_pkt_initial_handshake(true,NULL,NULL, &sess->thread_session_id, false);
 
 	while (__sync_fetch_and_add(&glovars.shutdown,0)==0) {
 		if (myds->available_data_out()) {
