@@ -327,7 +327,7 @@ void SQLite3_Server_session_handler(MySQL_Session *sess, void *_pa, PtrSize_t *p
 		SQLite3_Session *sqlite_sess = (SQLite3_Session *)sess->thread->gen_args;
 		sqlite3 *db = sqlite_sess->sessdb->get_db();
 		uint16_t status=2; // autocommit
-		if (sqlite3_get_autocommit(db)==0) {
+		if ((*proxy_sqlite3_get_autocommit)(db)==0) {
 			status = 3; // autocommit + transaction
 		}
 		GloSQLite3Server->send_MySQL_OK(&sess->client_myds->myprot, NULL, 0, status);
@@ -621,7 +621,7 @@ __run_query:
 #endif // TEST_AURORA || TEST_GALERA || TEST_GROUPREP
 		sqlite3 *db = sqlite_sess->sessdb->get_db();
 		bool in_trans = false;
-		if (sqlite3_get_autocommit(db)==0) {
+		if ((*proxy_sqlite3_get_autocommit)(db)==0) {
 			in_trans = true;
 		}
 		sess->SQLite3_to_MySQL(resultset, error, affected_rows, &sess->client_myds->myprot, in_trans);
@@ -642,7 +642,7 @@ SQLite3_Session::SQLite3_Session() {
 
 SQLite3_Session::~SQLite3_Session() {
 	sqlite3 *db = sessdb->get_db();
-	if (sqlite3_get_autocommit(db)==0) {
+	if ((*proxy_sqlite3_get_autocommit)(db)==0) {
 		sessdb->execute((char *)"COMMIT");
 	}
 	delete sessdb;
@@ -683,7 +683,7 @@ static void *child_mysql(void *arg) {
 	fds[0].revents=0;
 	fds[0].events=POLLIN|POLLOUT;
 	free(arg);
-	sess->client_myds->myprot.generate_pkt_initial_handshake(true,NULL,NULL, &sess->thread_session_id);
+	sess->client_myds->myprot.generate_pkt_initial_handshake(true,NULL,NULL, &sess->thread_session_id, false);
 
 	while (__sync_fetch_and_add(&glovars.shutdown,0)==0) {
 		if (myds->available_data_out()) {
@@ -995,8 +995,7 @@ void SQLite3_Server::populate_galera_table(MySQL_Session *sess) {
 			rc=sqlite3_bind_int64(statement, 9, 0); ASSERT_SQLITE_OK(rc, sessdb);
 			rc=sqlite3_bind_text(statement, 10, (char *)"Primary", -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, sessdb);
 
-			char *pxt_maint_mode = rand()%2==0?(char*)"ENABLED":(char*)"DISABLED";
-			rc=sqlite3_bind_text(statement, 11, pxt_maint_mode, -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, sessdb);
+			rc=sqlite3_bind_text(statement, 11, (char *)"DISABLED", -1, SQLITE_TRANSIENT); ASSERT_SQLITE_OK(rc, sessdb);
 
 			SAFE_SQLITE3_STEP2(statement);
 			rc=sqlite3_clear_bindings(statement); ASSERT_SQLITE_OK(rc, sessdb);
@@ -1163,7 +1162,7 @@ bool SQLite3_Server::init() {
 	tables_defs_galera = new std::vector<table_def_t *>;
 	insert_into_tables_defs(tables_defs_galera,
 		(const char *)"HOST_STATUS_GALERA",
-		(const char *)"CREATE TABLE HOST_STATUS_GALERA (hostgroup_id INT NOT NULL , hostname VARCHAR NOT NULL , port INT NOT NULL , wsrep_local_state VARCHAR , read_only VARCHAR , wsrep_local_recv_queue VARCHAR , wsrep_desync VARCHAR , wsrep_reject_queries VARCHAR , wsrep_sst_donor_rejects_queries VARCHAR , wsrep_cluster_status VARCHAR , pxc_maint_mode VARCHAR , PRIMARY KEY (hostgroup_id, hostname, port))");
+		(const char *)"CREATE TABLE HOST_STATUS_GALERA (hostgroup_id INT NOT NULL , hostname VARCHAR NOT NULL , port INT NOT NULL , wsrep_local_state VARCHAR , read_only VARCHAR , wsrep_local_recv_queue VARCHAR , wsrep_desync VARCHAR , wsrep_reject_queries VARCHAR , wsrep_sst_donor_rejects_queries VARCHAR , wsrep_cluster_status VARCHAR , pxc_maint_mode VARCHAR NOT NULL CHECK (pxc_maint_mode IN ('DISABLED', 'SHUTDOWN', 'MAINTENANCE')) DEFAULT 'DISABLED' , PRIMARY KEY (hostgroup_id, hostname, port))");
 	check_and_build_standard_tables(sessdb, tables_defs_galera);
 	GloAdmin->enable_galera_testing();
 #endif // TEST_GALERA
@@ -1272,7 +1271,7 @@ void SQLite3_Server::send_MySQL_OK(MySQL_Protocol *myprot, char *msg, int rows,
 	assert(myprot);
 	MySQL_Data_Stream *myds=myprot->get_myds();
 	myds->DSS=STATE_QUERY_SENT_DS;
-	myprot->generate_pkt_OK(true,NULL,NULL,1,rows,0,status,0,msg);
+	myprot->generate_pkt_OK(true,NULL,NULL,1,rows,0,status,0,msg,false);
 	myds->DSS=STATE_SLEEP;
 }
 
